**CryptoDataHub** is a repository of cryptography-related data available under a free license. The main goal of the
repository is to support cryptographic library tester and client/server cryptographic settings analyzer applications
such as `CryptoLyzer <https://cryptolyzer.readthedocs.io/>`__ with reliable and freely available data.

--------------
Python Wrapper
--------------

Installation
============

.. code:: shell

   pip install cryptodatahub

Support
=======

Implementations
---------------

-  CPython (2.7, 3.3+)
-  PyPy (2.7, 3.5+)

Operating systems
-----------------

-  Linux
-  macOS
-  Windows

-------------
Documentation
-------------

Detailed `documentation <https://cryptodatahub.readthedocs.io>`__ is available on the project's
`Read the Docs <https://readthedocs.com>`__ site.

-------
License
-------

The `code <https://gitlab.com/coroner/cryptodatahub>`__ is available under the terms of
`Mozilla Public License Version 2.0 <https://www.mozilla.org/en-US/MPL/2.0/>`__ (MPL 2.0).

A non-comprehensive, but straightforward description of MPL 2.0 can be found at
`Choose an open source license <https://choosealicense.com/licenses#mpl-2.0>`__ website.

-------
Credits
-------

-  `NLnet Foundation <https://nlnet.nl>`__ and `NGI Assure <https://www.assure.ngi.eu>`__, supports the project part of
   the `Next Generation Internet <https://ngi.eu>`__ initiative.
